// Copyright (c) Microsoft Corporation
// Licensed under the MIT license.
import { NoTarget } from "@typespec/compiler";
import { getHttpService, getServers } from "@typespec/http";
import { createModule } from "../ctx.js";
import { reportDiagnostic } from "../lib.js";
import { emitRawServer } from "./server/index.js";
import { emitRouter } from "./server/router.js";
/**
 * Emits bindings for the service to be carried over the HTTP protocol.
 */
export async function emitHttp(ctx) {
    const [httpService, diagnostics] = getHttpService(ctx.program, ctx.service.type);
    const diagnosticsAreError = diagnostics.some((d) => d.severity === "error");
    if (diagnosticsAreError) {
        reportDiagnostic(ctx.program, {
            code: "http-emit-disabled",
            target: NoTarget,
            messageId: "default",
        });
        return;
    }
    const servers = getServers(ctx.program, ctx.service.type) ?? [];
    const httpModule = createModule("http", ctx.rootModule);
    const httpContext = {
        ...ctx,
        httpService,
        httpModule,
        servers,
    };
    const operationsModule = createModule("operations", httpModule);
    const serverRawModule = emitRawServer(httpContext, operationsModule);
    emitRouter(httpContext, httpService, serverRawModule);
}
//# sourceMappingURL=index.js.map